@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Interfaces for session utility.
-
-$Id: interfaces.py 87351 2008-06-12 21:02:43Z gary $
 """
 from zope.interface import Interface
 from zope.interface.common.mapping import IMapping, IReadMapping, IWriteMapping
@@ -111,11 +109,13 @@ class ISession(Interface):
         given product id, determining the client id, and returning the
         relevant ISessionPkgData.
 
+        Caution: This method implicitly creates a new session for the user
+                 when it does not exist yet.
+
         """
 
     def get(product_id, default=None):
-        """Return the relevant ISessionPkgData or default if not
-        available"""
+        """Return the relevant ISessionPkgData or default if not available."""
 
 
 class ISessionData(IReadMapping, IMapping):
