@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,15 +12,15 @@
 #
 ##############################################################################
 """Session tests
-
-$Id: tests.py 98144 2009-03-16 15:46:45Z nadako $
 """
 from cStringIO import StringIO
-import unittest, os, os.path
-
-import zope.component
-from zope.testing import doctest, cleanup
+from zope.testing import cleanup
+import doctest
+import os
+import os.path
 import transaction
+import unittest
+import zope.component
 
 from zope.component import provideHandler, getGlobalSiteManager
 from zope.session.interfaces import IClientId, IClientIdManager, ISession
@@ -127,6 +127,33 @@ def testConflicts():
     Q.E.D.
     """
 
+def testSessionIterationBug():
+    """
+
+    The zope.session.session.Session ISession implementation defines
+    an `__iter__` method that raises NotImplementedError in order to
+    avoid an infinite loop if iteration or a test for containment is
+    attempted on an instance.
+
+    >>> import zope.session.session
+    >>> request = setUp()
+    >>> session = zope.session.session.Session(request)
+    >>> try:
+    ...     "blah" in session
+    ... except TypeError:
+    ...     pass
+    ... else:
+    ...     raise Exception("Should have raised TypeError")
+
+    >>> for i in session:
+    ...     raise Exception("Should have raised NotImplementedError")
+    Traceback (most recent call last):
+    ...
+    NotImplementedError
+
+    >>> tearDown()
+    """
+
 
 def test_suite():
     suite = unittest.TestSuite()
